@@ -79,6 +79,24 @@ class VOLUME_UL_grids(bpy_types.UIList, bpy_types._GenericUI):
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_extended(self):
         ''' 
 
@@ -262,6 +280,24 @@ class DATA_PT_context_volume(DataButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_extended(self):
         ''' 
 
@@ -454,6 +490,24 @@ class DATA_PT_custom_props_volume(DataButtonsPanel, rna_prop_ui.PropertyPanel,
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_extended(self):
         ''' 
 
@@ -640,6 +694,24 @@ class DATA_PT_volume_file(DataButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_extended(self):
         ''' 
 
@@ -826,6 +898,24 @@ class DATA_PT_volume_grids(DataButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_extended(self):
         ''' 
 
@@ -1012,6 +1102,24 @@ class DATA_PT_volume_render(DataButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_extended(self):
         ''' 
 
@@ -1198,6 +1306,24 @@ class DATA_PT_volume_viewport_display(DataButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_extended(self):
         ''' 
 
@@ -1393,6 +1519,24 @@ class DATA_PT_volume_viewport_display_slicing(
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_extended(self):
         ''' 
 
