@@ -3,6 +3,8 @@ import typing
 import bpy_types
 import bl_ui.properties_grease_pencil_common
 
+GenericType = typing.TypeVar("GenericType")
+
 
 class RENDER_PT_context(bpy_types.Panel, bpy_types._GenericUI):
     bl_context = None
@@ -6070,3 +6072,11 @@ class RENDER_PT_simplify_viewport(RenderButtonsPanel, bpy_types.Panel,
 
         '''
         pass
+
+
+def draw_curves_settings(context):
+    ''' 
+
+    '''
+
+    pass
