@@ -8,12 +8,12 @@ GenericType = typing.TypeVar("GenericType")
 def add_target(override_context: typing.
                Union[typing.Dict, 'bpy.types.Context'] = None,
                execution_context: typing.Union[str, int] = None,
-               undo: bool = None):
-    ''' Add a target to the constraint :file: startup/bl_operators/constraint.py\:25 <https://developer.blender.org/diffusion/B/browse/master/release/scripts/startup/bl_operators/constraint.py$25> _
+               undo: typing.Optional[bool] = None):
+    ''' Add a target to the constraint :file: `startup/bl_operators/constraint.py\:25 <https://developer.blender.org/diffusion/B/browse/master/release/scripts/startup/bl_operators/constraint.py$25>`_
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
@@ -22,22 +22,22 @@ def add_target(override_context: typing.
 def apply(override_context: typing.Union[typing.
                                          Dict, 'bpy.types.Context'] = None,
           execution_context: typing.Union[str, int] = None,
-          undo: bool = None,
+          undo: typing.Optional[bool] = None,
           *,
-          constraint: str = "",
-          owner: typing.Union[str, int] = 'OBJECT',
-          report: bool = False):
+          constraint: typing.Union[str, typing.Any] = "",
+          owner: typing.Optional[typing.Any] = 'OBJECT',
+          report: typing.Union[bool, typing.Any] = False):
     ''' Apply constraint and remove from the stack
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param constraint: Constraint, Name of the constraint to edit
-    :type constraint: str
-    :param owner: Owner, The owner of this constraint * OBJECT Object -- Edit a constraint on the active object. * BONE Bone -- Edit a constraint on the active bone.
-    :type owner: typing.Union[str, int]
+    :type constraint: typing.Union[str, typing.Any]
+    :param owner: Owner, The owner of this constraint * ``OBJECT`` Object -- Edit a constraint on the active object. * ``BONE`` Bone -- Edit a constraint on the active bone.
+    :type owner: typing.Optional[typing.Any]
     :param report: Report, Create a notification after the operation
-    :type report: bool
+    :type report: typing.Union[bool, typing.Any]
     '''
 
     pass
@@ -46,19 +46,19 @@ def apply(override_context: typing.Union[typing.
 def childof_clear_inverse(override_context: typing.
                           Union[typing.Dict, 'bpy.types.Context'] = None,
                           execution_context: typing.Union[str, int] = None,
-                          undo: bool = None,
+                          undo: typing.Optional[bool] = None,
                           *,
-                          constraint: str = "",
-                          owner: typing.Union[str, int] = 'OBJECT'):
+                          constraint: typing.Union[str, typing.Any] = "",
+                          owner: typing.Optional[typing.Any] = 'OBJECT'):
     ''' Clear inverse correction for Child Of constraint
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param constraint: Constraint, Name of the constraint to edit
-    :type constraint: str
-    :param owner: Owner, The owner of this constraint * OBJECT Object -- Edit a constraint on the active object. * BONE Bone -- Edit a constraint on the active bone.
-    :type owner: typing.Union[str, int]
+    :type constraint: typing.Union[str, typing.Any]
+    :param owner: Owner, The owner of this constraint * ``OBJECT`` Object -- Edit a constraint on the active object. * ``BONE`` Bone -- Edit a constraint on the active bone.
+    :type owner: typing.Optional[typing.Any]
     '''
 
     pass
@@ -67,19 +67,19 @@ def childof_clear_inverse(override_context: typing.
 def childof_set_inverse(override_context: typing.
                         Union[typing.Dict, 'bpy.types.Context'] = None,
                         execution_context: typing.Union[str, int] = None,
-                        undo: bool = None,
+                        undo: typing.Optional[bool] = None,
                         *,
-                        constraint: str = "",
-                        owner: typing.Union[str, int] = 'OBJECT'):
+                        constraint: typing.Union[str, typing.Any] = "",
+                        owner: typing.Optional[typing.Any] = 'OBJECT'):
     ''' Set inverse correction for Child Of constraint
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param constraint: Constraint, Name of the constraint to edit
-    :type constraint: str
-    :param owner: Owner, The owner of this constraint * OBJECT Object -- Edit a constraint on the active object. * BONE Bone -- Edit a constraint on the active bone.
-    :type owner: typing.Union[str, int]
+    :type constraint: typing.Union[str, typing.Any]
+    :param owner: Owner, The owner of this constraint * ``OBJECT`` Object -- Edit a constraint on the active object. * ``BONE`` Bone -- Edit a constraint on the active bone.
+    :type owner: typing.Optional[typing.Any]
     '''
 
     pass
@@ -88,22 +88,22 @@ def childof_set_inverse(override_context: typing.
 def copy(override_context: typing.Union[typing.
                                         Dict, 'bpy.types.Context'] = None,
          execution_context: typing.Union[str, int] = None,
-         undo: bool = None,
+         undo: typing.Optional[bool] = None,
          *,
-         constraint: str = "",
-         owner: typing.Union[str, int] = 'OBJECT',
-         report: bool = False):
+         constraint: typing.Union[str, typing.Any] = "",
+         owner: typing.Optional[typing.Any] = 'OBJECT',
+         report: typing.Union[bool, typing.Any] = False):
     ''' Duplicate constraint at the same position in the stack
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param constraint: Constraint, Name of the constraint to edit
-    :type constraint: str
-    :param owner: Owner, The owner of this constraint * OBJECT Object -- Edit a constraint on the active object. * BONE Bone -- Edit a constraint on the active bone.
-    :type owner: typing.Union[str, int]
+    :type constraint: typing.Union[str, typing.Any]
+    :param owner: Owner, The owner of this constraint * ``OBJECT`` Object -- Edit a constraint on the active object. * ``BONE`` Bone -- Edit a constraint on the active bone.
+    :type owner: typing.Optional[typing.Any]
     :param report: Report, Create a notification after the operation
-    :type report: bool
+    :type report: typing.Union[bool, typing.Any]
     '''
 
     pass
@@ -112,19 +112,19 @@ def copy(override_context: typing.Union[typing.
 def copy_to_selected(override_context: typing.
                      Union[typing.Dict, 'bpy.types.Context'] = None,
                      execution_context: typing.Union[str, int] = None,
-                     undo: bool = None,
+                     undo: typing.Optional[bool] = None,
                      *,
-                     constraint: str = "",
-                     owner: typing.Union[str, int] = 'OBJECT'):
+                     constraint: typing.Union[str, typing.Any] = "",
+                     owner: typing.Optional[typing.Any] = 'OBJECT'):
     ''' Copy constraint to other selected objects/bones
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param constraint: Constraint, Name of the constraint to edit
-    :type constraint: str
-    :param owner: Owner, The owner of this constraint * OBJECT Object -- Edit a constraint on the active object. * BONE Bone -- Edit a constraint on the active bone.
-    :type owner: typing.Union[str, int]
+    :type constraint: typing.Union[str, typing.Any]
+    :param owner: Owner, The owner of this constraint * ``OBJECT`` Object -- Edit a constraint on the active object. * ``BONE`` Bone -- Edit a constraint on the active bone.
+    :type owner: typing.Optional[typing.Any]
     '''
 
     pass
@@ -133,22 +133,22 @@ def copy_to_selected(override_context: typing.
 def delete(override_context: typing.Union[typing.
                                           Dict, 'bpy.types.Context'] = None,
            execution_context: typing.Union[str, int] = None,
-           undo: bool = None,
+           undo: typing.Optional[bool] = None,
            *,
-           constraint: str = "",
-           owner: typing.Union[str, int] = 'OBJECT',
-           report: bool = False):
+           constraint: typing.Union[str, typing.Any] = "",
+           owner: typing.Optional[typing.Any] = 'OBJECT',
+           report: typing.Union[bool, typing.Any] = False):
     ''' Remove constraint from constraint stack
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param constraint: Constraint, Name of the constraint to edit
-    :type constraint: str
-    :param owner: Owner, The owner of this constraint * OBJECT Object -- Edit a constraint on the active object. * BONE Bone -- Edit a constraint on the active bone.
-    :type owner: typing.Union[str, int]
+    :type constraint: typing.Union[str, typing.Any]
+    :param owner: Owner, The owner of this constraint * ``OBJECT`` Object -- Edit a constraint on the active object. * ``BONE`` Bone -- Edit a constraint on the active bone.
+    :type owner: typing.Optional[typing.Any]
     :param report: Report, Create a notification after the operation
-    :type report: bool
+    :type report: typing.Union[bool, typing.Any]
     '''
 
     pass
@@ -157,12 +157,12 @@ def delete(override_context: typing.Union[typing.
 def disable_keep_transform(override_context: typing.
                            Union[typing.Dict, 'bpy.types.Context'] = None,
                            execution_context: typing.Union[str, int] = None,
-                           undo: bool = None):
-    ''' Set the influence of this constraint to zero while trying to maintain the object's transformation. Other active constraints can still influence the final transformation :file: startup/bl_operators/constraint.py\:85 <https://developer.blender.org/diffusion/B/browse/master/release/scripts/startup/bl_operators/constraint.py$85> _
+                           undo: typing.Optional[bool] = None):
+    ''' Set the influence of this constraint to zero while trying to maintain the object's transformation. Other active constraints can still influence the final transformation :file: `startup/bl_operators/constraint.py\:85 <https://developer.blender.org/diffusion/B/browse/master/release/scripts/startup/bl_operators/constraint.py$85>`_
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
@@ -171,25 +171,25 @@ def disable_keep_transform(override_context: typing.
 def followpath_path_animate(override_context: typing.
                             Union[typing.Dict, 'bpy.types.Context'] = None,
                             execution_context: typing.Union[str, int] = None,
-                            undo: bool = None,
+                            undo: typing.Optional[bool] = None,
                             *,
-                            constraint: str = "",
-                            owner: typing.Union[str, int] = 'OBJECT',
-                            frame_start: int = 1,
-                            length: int = 100):
+                            constraint: typing.Union[str, typing.Any] = "",
+                            owner: typing.Optional[typing.Any] = 'OBJECT',
+                            frame_start: typing.Optional[typing.Any] = 1,
+                            length: typing.Optional[typing.Any] = 100):
     ''' Add default animation for path used by constraint if it isn't animated already
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param constraint: Constraint, Name of the constraint to edit
-    :type constraint: str
-    :param owner: Owner, The owner of this constraint * OBJECT Object -- Edit a constraint on the active object. * BONE Bone -- Edit a constraint on the active bone.
-    :type owner: typing.Union[str, int]
+    :type constraint: typing.Union[str, typing.Any]
+    :param owner: Owner, The owner of this constraint * ``OBJECT`` Object -- Edit a constraint on the active object. * ``BONE`` Bone -- Edit a constraint on the active bone.
+    :type owner: typing.Optional[typing.Any]
     :param frame_start: Start Frame, First frame of path animation
-    :type frame_start: int
+    :type frame_start: typing.Optional[typing.Any]
     :param length: Length, Number of frames that path animation should take
-    :type length: int
+    :type length: typing.Optional[typing.Any]
     '''
 
     pass
@@ -198,19 +198,19 @@ def followpath_path_animate(override_context: typing.
 def limitdistance_reset(override_context: typing.
                         Union[typing.Dict, 'bpy.types.Context'] = None,
                         execution_context: typing.Union[str, int] = None,
-                        undo: bool = None,
+                        undo: typing.Optional[bool] = None,
                         *,
-                        constraint: str = "",
-                        owner: typing.Union[str, int] = 'OBJECT'):
+                        constraint: typing.Union[str, typing.Any] = "",
+                        owner: typing.Optional[typing.Any] = 'OBJECT'):
     ''' Reset limiting distance for Limit Distance Constraint
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param constraint: Constraint, Name of the constraint to edit
-    :type constraint: str
-    :param owner: Owner, The owner of this constraint * OBJECT Object -- Edit a constraint on the active object. * BONE Bone -- Edit a constraint on the active bone.
-    :type owner: typing.Union[str, int]
+    :type constraint: typing.Union[str, typing.Any]
+    :param owner: Owner, The owner of this constraint * ``OBJECT`` Object -- Edit a constraint on the active object. * ``BONE`` Bone -- Edit a constraint on the active bone.
+    :type owner: typing.Optional[typing.Any]
     '''
 
     pass
@@ -219,19 +219,19 @@ def limitdistance_reset(override_context: typing.
 def move_down(override_context: typing.Union[typing.
                                              Dict, 'bpy.types.Context'] = None,
               execution_context: typing.Union[str, int] = None,
-              undo: bool = None,
+              undo: typing.Optional[bool] = None,
               *,
-              constraint: str = "",
-              owner: typing.Union[str, int] = 'OBJECT'):
+              constraint: typing.Union[str, typing.Any] = "",
+              owner: typing.Optional[typing.Any] = 'OBJECT'):
     ''' Move constraint down in constraint stack
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param constraint: Constraint, Name of the constraint to edit
-    :type constraint: str
-    :param owner: Owner, The owner of this constraint * OBJECT Object -- Edit a constraint on the active object. * BONE Bone -- Edit a constraint on the active bone.
-    :type owner: typing.Union[str, int]
+    :type constraint: typing.Union[str, typing.Any]
+    :param owner: Owner, The owner of this constraint * ``OBJECT`` Object -- Edit a constraint on the active object. * ``BONE`` Bone -- Edit a constraint on the active bone.
+    :type owner: typing.Optional[typing.Any]
     '''
 
     pass
@@ -240,22 +240,22 @@ def move_down(override_context: typing.Union[typing.
 def move_to_index(override_context: typing.
                   Union[typing.Dict, 'bpy.types.Context'] = None,
                   execution_context: typing.Union[str, int] = None,
-                  undo: bool = None,
+                  undo: typing.Optional[bool] = None,
                   *,
-                  constraint: str = "",
-                  owner: typing.Union[str, int] = 'OBJECT',
-                  index: int = 0):
+                  constraint: typing.Union[str, typing.Any] = "",
+                  owner: typing.Optional[typing.Any] = 'OBJECT',
+                  index: typing.Optional[typing.Any] = 0):
     ''' Change the constraint's position in the list so it evaluates after the set number of others
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param constraint: Constraint, Name of the constraint to edit
-    :type constraint: str
-    :param owner: Owner, The owner of this constraint * OBJECT Object -- Edit a constraint on the active object. * BONE Bone -- Edit a constraint on the active bone.
-    :type owner: typing.Union[str, int]
+    :type constraint: typing.Union[str, typing.Any]
+    :param owner: Owner, The owner of this constraint * ``OBJECT`` Object -- Edit a constraint on the active object. * ``BONE`` Bone -- Edit a constraint on the active bone.
+    :type owner: typing.Optional[typing.Any]
     :param index: Index, The index to move the constraint to
-    :type index: int
+    :type index: typing.Optional[typing.Any]
     '''
 
     pass
@@ -264,19 +264,19 @@ def move_to_index(override_context: typing.
 def move_up(override_context: typing.Union[typing.
                                            Dict, 'bpy.types.Context'] = None,
             execution_context: typing.Union[str, int] = None,
-            undo: bool = None,
+            undo: typing.Optional[bool] = None,
             *,
-            constraint: str = "",
-            owner: typing.Union[str, int] = 'OBJECT'):
+            constraint: typing.Union[str, typing.Any] = "",
+            owner: typing.Optional[typing.Any] = 'OBJECT'):
     ''' Move constraint up in constraint stack
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param constraint: Constraint, Name of the constraint to edit
-    :type constraint: str
-    :param owner: Owner, The owner of this constraint * OBJECT Object -- Edit a constraint on the active object. * BONE Bone -- Edit a constraint on the active bone.
-    :type owner: typing.Union[str, int]
+    :type constraint: typing.Union[str, typing.Any]
+    :param owner: Owner, The owner of this constraint * ``OBJECT`` Object -- Edit a constraint on the active object. * ``BONE`` Bone -- Edit a constraint on the active bone.
+    :type owner: typing.Optional[typing.Any]
     '''
 
     pass
@@ -285,12 +285,12 @@ def move_up(override_context: typing.Union[typing.
 def normalize_target_weights(override_context: typing.
                              Union[typing.Dict, 'bpy.types.Context'] = None,
                              execution_context: typing.Union[str, int] = None,
-                             undo: bool = None):
-    ''' Normalize weights of all target bones :file: startup/bl_operators/constraint.py\:60 <https://developer.blender.org/diffusion/B/browse/master/release/scripts/startup/bl_operators/constraint.py$60> _
+                             undo: typing.Optional[bool] = None):
+    ''' Normalize weights of all target bones :file: `startup/bl_operators/constraint.py\:60 <https://developer.blender.org/diffusion/B/browse/master/release/scripts/startup/bl_operators/constraint.py$60>`_
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
@@ -300,19 +300,19 @@ def objectsolver_clear_inverse(
         override_context: typing.Union[typing.
                                        Dict, 'bpy.types.Context'] = None,
         execution_context: typing.Union[str, int] = None,
-        undo: bool = None,
+        undo: typing.Optional[bool] = None,
         *,
-        constraint: str = "",
-        owner: typing.Union[str, int] = 'OBJECT'):
+        constraint: typing.Union[str, typing.Any] = "",
+        owner: typing.Optional[typing.Any] = 'OBJECT'):
     ''' Clear inverse correction for Object Solver constraint
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param constraint: Constraint, Name of the constraint to edit
-    :type constraint: str
-    :param owner: Owner, The owner of this constraint * OBJECT Object -- Edit a constraint on the active object. * BONE Bone -- Edit a constraint on the active bone.
-    :type owner: typing.Union[str, int]
+    :type constraint: typing.Union[str, typing.Any]
+    :param owner: Owner, The owner of this constraint * ``OBJECT`` Object -- Edit a constraint on the active object. * ``BONE`` Bone -- Edit a constraint on the active bone.
+    :type owner: typing.Optional[typing.Any]
     '''
 
     pass
@@ -321,19 +321,19 @@ def objectsolver_clear_inverse(
 def objectsolver_set_inverse(override_context: typing.
                              Union[typing.Dict, 'bpy.types.Context'] = None,
                              execution_context: typing.Union[str, int] = None,
-                             undo: bool = None,
+                             undo: typing.Optional[bool] = None,
                              *,
-                             constraint: str = "",
-                             owner: typing.Union[str, int] = 'OBJECT'):
+                             constraint: typing.Union[str, typing.Any] = "",
+                             owner: typing.Optional[typing.Any] = 'OBJECT'):
     ''' Set inverse correction for Object Solver constraint
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param constraint: Constraint, Name of the constraint to edit
-    :type constraint: str
-    :param owner: Owner, The owner of this constraint * OBJECT Object -- Edit a constraint on the active object. * BONE Bone -- Edit a constraint on the active bone.
-    :type owner: typing.Union[str, int]
+    :type constraint: typing.Union[str, typing.Any]
+    :param owner: Owner, The owner of this constraint * ``OBJECT`` Object -- Edit a constraint on the active object. * ``BONE`` Bone -- Edit a constraint on the active bone.
+    :type owner: typing.Optional[typing.Any]
     '''
 
     pass
@@ -342,16 +342,16 @@ def objectsolver_set_inverse(override_context: typing.
 def remove_target(override_context: typing.
                   Union[typing.Dict, 'bpy.types.Context'] = None,
                   execution_context: typing.Union[str, int] = None,
-                  undo: bool = None,
+                  undo: typing.Optional[bool] = None,
                   *,
-                  index: int = 0):
+                  index: typing.Optional[typing.Any] = 0):
     ''' Remove the target from the constraint
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param index: index
-    :type index: int
+    :type index: typing.Optional[typing.Any]
     '''
 
     pass
@@ -360,19 +360,19 @@ def remove_target(override_context: typing.
 def stretchto_reset(override_context: typing.
                     Union[typing.Dict, 'bpy.types.Context'] = None,
                     execution_context: typing.Union[str, int] = None,
-                    undo: bool = None,
+                    undo: typing.Optional[bool] = None,
                     *,
-                    constraint: str = "",
-                    owner: typing.Union[str, int] = 'OBJECT'):
+                    constraint: typing.Union[str, typing.Any] = "",
+                    owner: typing.Optional[typing.Any] = 'OBJECT'):
     ''' Reset original length of bone for Stretch To Constraint
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param constraint: Constraint, Name of the constraint to edit
-    :type constraint: str
-    :param owner: Owner, The owner of this constraint * OBJECT Object -- Edit a constraint on the active object. * BONE Bone -- Edit a constraint on the active bone.
-    :type owner: typing.Union[str, int]
+    :type constraint: typing.Union[str, typing.Any]
+    :param owner: Owner, The owner of this constraint * ``OBJECT`` Object -- Edit a constraint on the active object. * ``BONE`` Bone -- Edit a constraint on the active bone.
+    :type owner: typing.Optional[typing.Any]
     '''
 
     pass
