@@ -8,16 +8,16 @@ GenericType = typing.TypeVar("GenericType")
 def case_set(override_context: typing.Union[typing.
                                             Dict, 'bpy.types.Context'] = None,
              execution_context: typing.Union[str, int] = None,
-             undo: bool = None,
+             undo: typing.Optional[bool] = None,
              *,
-             case: typing.Union[str, int] = 'LOWER'):
+             case: typing.Optional[typing.Any] = 'LOWER'):
     ''' Set font case
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param case: Case, Lower or upper case
-    :type case: typing.Union[str, int]
+    :type case: typing.Optional[typing.Any]
     '''
 
     pass
@@ -26,12 +26,12 @@ def case_set(override_context: typing.Union[typing.
 def case_toggle(override_context: typing.
                 Union[typing.Dict, 'bpy.types.Context'] = None,
                 execution_context: typing.Union[str, int] = None,
-                undo: bool = None):
+                undo: typing.Optional[bool] = None):
     ''' Toggle font case
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
@@ -40,16 +40,16 @@ def case_toggle(override_context: typing.
 def change_character(override_context: typing.
                      Union[typing.Dict, 'bpy.types.Context'] = None,
                      execution_context: typing.Union[str, int] = None,
-                     undo: bool = None,
+                     undo: typing.Optional[bool] = None,
                      *,
-                     delta: int = 1):
+                     delta: typing.Optional[typing.Any] = 1):
     ''' Change font character code
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param delta: Delta, Number to increase or decrease character code with
-    :type delta: int
+    :type delta: typing.Optional[typing.Any]
     '''
 
     pass
@@ -58,16 +58,16 @@ def change_character(override_context: typing.
 def change_spacing(override_context: typing.
                    Union[typing.Dict, 'bpy.types.Context'] = None,
                    execution_context: typing.Union[str, int] = None,
-                   undo: bool = None,
+                   undo: typing.Optional[bool] = None,
                    *,
-                   delta: int = 1):
+                   delta: typing.Optional[typing.Any] = 1):
     ''' Change font spacing
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param delta: Delta, Amount to decrease or increase character spacing with
-    :type delta: int
+    :type delta: typing.Optional[typing.Any]
     '''
 
     pass
@@ -76,16 +76,16 @@ def change_spacing(override_context: typing.
 def delete(override_context: typing.Union[typing.
                                           Dict, 'bpy.types.Context'] = None,
            execution_context: typing.Union[str, int] = None,
-           undo: bool = None,
+           undo: typing.Optional[bool] = None,
            *,
-           type: typing.Union[str, int] = 'PREVIOUS_CHARACTER'):
+           type: typing.Optional[typing.Any] = 'PREVIOUS_CHARACTER'):
     ''' Delete text by cursor position
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param type: Type, Which part of the text to delete
-    :type type: typing.Union[str, int]
+    :type type: typing.Optional[typing.Any]
     '''
 
     pass
@@ -94,12 +94,12 @@ def delete(override_context: typing.Union[typing.
 def line_break(override_context: typing.
                Union[typing.Dict, 'bpy.types.Context'] = None,
                execution_context: typing.Union[str, int] = None,
-               undo: bool = None):
+               undo: typing.Optional[bool] = None):
     ''' Insert line break at cursor position
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
@@ -108,16 +108,16 @@ def line_break(override_context: typing.
 def move(override_context: typing.Union[typing.
                                         Dict, 'bpy.types.Context'] = None,
          execution_context: typing.Union[str, int] = None,
-         undo: bool = None,
+         undo: typing.Optional[bool] = None,
          *,
-         type: typing.Union[str, int] = 'LINE_BEGIN'):
+         type: typing.Optional[typing.Any] = 'LINE_BEGIN'):
     ''' Move cursor to position type
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param type: Type, Where to move cursor to
-    :type type: typing.Union[str, int]
+    :type type: typing.Optional[typing.Any]
     '''
 
     pass
@@ -126,16 +126,16 @@ def move(override_context: typing.Union[typing.
 def move_select(override_context: typing.
                 Union[typing.Dict, 'bpy.types.Context'] = None,
                 execution_context: typing.Union[str, int] = None,
-                undo: bool = None,
+                undo: typing.Optional[bool] = None,
                 *,
-                type: typing.Union[str, int] = 'LINE_BEGIN'):
+                type: typing.Optional[typing.Any] = 'LINE_BEGIN'):
     ''' Move the cursor while selecting
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param type: Type, Where to move cursor to, to make a selection
-    :type type: typing.Union[str, int]
+    :type type: typing.Optional[typing.Any]
     '''
 
     pass
@@ -144,82 +144,82 @@ def move_select(override_context: typing.
 def open(override_context: typing.Union[typing.
                                         Dict, 'bpy.types.Context'] = None,
          execution_context: typing.Union[str, int] = None,
-         undo: bool = None,
+         undo: typing.Optional[bool] = None,
          *,
-         filepath: str = "",
-         hide_props_region: bool = True,
-         filter_blender: bool = False,
-         filter_backup: bool = False,
-         filter_image: bool = False,
-         filter_movie: bool = False,
-         filter_python: bool = False,
-         filter_font: bool = True,
-         filter_sound: bool = False,
-         filter_text: bool = False,
-         filter_archive: bool = False,
-         filter_btx: bool = False,
-         filter_collada: bool = False,
-         filter_alembic: bool = False,
-         filter_usd: bool = False,
-         filter_obj: bool = False,
-         filter_volume: bool = False,
-         filter_folder: bool = True,
-         filter_blenlib: bool = False,
-         filemode: int = 9,
-         relative_path: bool = True,
-         display_type: typing.Union[str, int] = 'THUMBNAIL',
-         sort_method: typing.Union[str, int] = ''):
+         filepath: typing.Union[str, typing.Any] = "",
+         hide_props_region: typing.Union[bool, typing.Any] = True,
+         filter_blender: typing.Union[bool, typing.Any] = False,
+         filter_backup: typing.Union[bool, typing.Any] = False,
+         filter_image: typing.Union[bool, typing.Any] = False,
+         filter_movie: typing.Union[bool, typing.Any] = False,
+         filter_python: typing.Union[bool, typing.Any] = False,
+         filter_font: typing.Union[bool, typing.Any] = True,
+         filter_sound: typing.Union[bool, typing.Any] = False,
+         filter_text: typing.Union[bool, typing.Any] = False,
+         filter_archive: typing.Union[bool, typing.Any] = False,
+         filter_btx: typing.Union[bool, typing.Any] = False,
+         filter_collada: typing.Union[bool, typing.Any] = False,
+         filter_alembic: typing.Union[bool, typing.Any] = False,
+         filter_usd: typing.Union[bool, typing.Any] = False,
+         filter_obj: typing.Union[bool, typing.Any] = False,
+         filter_volume: typing.Union[bool, typing.Any] = False,
+         filter_folder: typing.Union[bool, typing.Any] = True,
+         filter_blenlib: typing.Union[bool, typing.Any] = False,
+         filemode: typing.Optional[typing.Any] = 9,
+         relative_path: typing.Union[bool, typing.Any] = True,
+         display_type: typing.Optional[typing.Any] = 'THUMBNAIL',
+         sort_method: typing.Union[str, int, typing.Any] = ''):
     ''' Load a new font from a file
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param filepath: File Path, Path to file
-    :type filepath: str
+    :type filepath: typing.Union[str, typing.Any]
     :param hide_props_region: Hide Operator Properties, Collapse the region displaying the operator settings
-    :type hide_props_region: bool
+    :type hide_props_region: typing.Union[bool, typing.Any]
     :param filter_blender: Filter .blend files
-    :type filter_blender: bool
+    :type filter_blender: typing.Union[bool, typing.Any]
     :param filter_backup: Filter .blend files
-    :type filter_backup: bool
+    :type filter_backup: typing.Union[bool, typing.Any]
     :param filter_image: Filter image files
-    :type filter_image: bool
+    :type filter_image: typing.Union[bool, typing.Any]
     :param filter_movie: Filter movie files
-    :type filter_movie: bool
+    :type filter_movie: typing.Union[bool, typing.Any]
     :param filter_python: Filter python files
-    :type filter_python: bool
+    :type filter_python: typing.Union[bool, typing.Any]
     :param filter_font: Filter font files
-    :type filter_font: bool
+    :type filter_font: typing.Union[bool, typing.Any]
     :param filter_sound: Filter sound files
-    :type filter_sound: bool
+    :type filter_sound: typing.Union[bool, typing.Any]
     :param filter_text: Filter text files
-    :type filter_text: bool
+    :type filter_text: typing.Union[bool, typing.Any]
     :param filter_archive: Filter archive files
-    :type filter_archive: bool
+    :type filter_archive: typing.Union[bool, typing.Any]
     :param filter_btx: Filter btx files
-    :type filter_btx: bool
+    :type filter_btx: typing.Union[bool, typing.Any]
     :param filter_collada: Filter COLLADA files
-    :type filter_collada: bool
+    :type filter_collada: typing.Union[bool, typing.Any]
     :param filter_alembic: Filter Alembic files
-    :type filter_alembic: bool
+    :type filter_alembic: typing.Union[bool, typing.Any]
     :param filter_usd: Filter USD files
-    :type filter_usd: bool
+    :type filter_usd: typing.Union[bool, typing.Any]
     :param filter_obj: Filter OBJ files
-    :type filter_obj: bool
+    :type filter_obj: typing.Union[bool, typing.Any]
     :param filter_volume: Filter OpenVDB volume files
-    :type filter_volume: bool
+    :type filter_volume: typing.Union[bool, typing.Any]
     :param filter_folder: Filter folders
-    :type filter_folder: bool
+    :type filter_folder: typing.Union[bool, typing.Any]
     :param filter_blenlib: Filter Blender IDs
-    :type filter_blenlib: bool
+    :type filter_blenlib: typing.Union[bool, typing.Any]
     :param filemode: File Browser Mode, The setting for the file browser mode to load a .blend file, a library or a special file
-    :type filemode: int
+    :type filemode: typing.Optional[typing.Any]
     :param relative_path: Relative Path, Select the file relative to the blend file
-    :type relative_path: bool
-    :param display_type: Display Type * DEFAULT Default -- Automatically determine display type for files. * LIST_VERTICAL Short List -- Display files as short list. * LIST_HORIZONTAL Long List -- Display files as a detailed list. * THUMBNAIL Thumbnails -- Display files as thumbnails.
-    :type display_type: typing.Union[str, int]
+    :type relative_path: typing.Union[bool, typing.Any]
+    :param display_type: Display Type * ``DEFAULT`` Default -- Automatically determine display type for files. * ``LIST_VERTICAL`` Short List -- Display files as short list. * ``LIST_HORIZONTAL`` Long List -- Display files as a detailed list. * ``THUMBNAIL`` Thumbnails -- Display files as thumbnails.
+    :type display_type: typing.Optional[typing.Any]
     :param sort_method: File sorting mode
-    :type sort_method: typing.Union[str, int]
+    :type sort_method: typing.Union[str, int, typing.Any]
     '''
 
     pass
@@ -228,12 +228,12 @@ def open(override_context: typing.Union[typing.
 def select_all(override_context: typing.
                Union[typing.Dict, 'bpy.types.Context'] = None,
                execution_context: typing.Union[str, int] = None,
-               undo: bool = None):
+               undo: typing.Optional[bool] = None):
     ''' Select all text
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
@@ -242,19 +242,19 @@ def select_all(override_context: typing.
 def style_set(override_context: typing.Union[typing.
                                              Dict, 'bpy.types.Context'] = None,
               execution_context: typing.Union[str, int] = None,
-              undo: bool = None,
+              undo: typing.Optional[bool] = None,
               *,
-              style: typing.Union[str, int] = 'BOLD',
-              clear: bool = False):
+              style: typing.Optional[typing.Any] = 'BOLD',
+              clear: typing.Union[bool, typing.Any] = False):
     ''' Set font style
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param style: Style, Style to set selection to
-    :type style: typing.Union[str, int]
+    :type style: typing.Optional[typing.Any]
     :param clear: Clear, Clear style rather than setting it
-    :type clear: bool
+    :type clear: typing.Union[bool, typing.Any]
     '''
 
     pass
@@ -263,16 +263,16 @@ def style_set(override_context: typing.Union[typing.
 def style_toggle(override_context: typing.
                  Union[typing.Dict, 'bpy.types.Context'] = None,
                  execution_context: typing.Union[str, int] = None,
-                 undo: bool = None,
+                 undo: typing.Optional[bool] = None,
                  *,
-                 style: typing.Union[str, int] = 'BOLD'):
+                 style: typing.Optional[typing.Any] = 'BOLD'):
     ''' Toggle font style
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param style: Style, Style to set selection to
-    :type style: typing.Union[str, int]
+    :type style: typing.Optional[typing.Any]
     '''
 
     pass
@@ -281,12 +281,12 @@ def style_toggle(override_context: typing.
 def text_copy(override_context: typing.Union[typing.
                                              Dict, 'bpy.types.Context'] = None,
               execution_context: typing.Union[str, int] = None,
-              undo: bool = None):
+              undo: typing.Optional[bool] = None):
     ''' Copy selected text to clipboard
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
@@ -295,12 +295,12 @@ def text_copy(override_context: typing.Union[typing.
 def text_cut(override_context: typing.Union[typing.
                                             Dict, 'bpy.types.Context'] = None,
              execution_context: typing.Union[str, int] = None,
-             undo: bool = None):
+             undo: typing.Optional[bool] = None):
     ''' Cut selected text to clipboard
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
@@ -309,19 +309,19 @@ def text_cut(override_context: typing.Union[typing.
 def text_insert(override_context: typing.
                 Union[typing.Dict, 'bpy.types.Context'] = None,
                 execution_context: typing.Union[str, int] = None,
-                undo: bool = None,
+                undo: typing.Optional[bool] = None,
                 *,
-                text: str = "",
-                accent: bool = False):
+                text: typing.Union[str, typing.Any] = "",
+                accent: typing.Union[bool, typing.Any] = False):
     ''' Insert text at cursor position
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param text: Text, Text to insert at the cursor position
-    :type text: str
+    :type text: typing.Union[str, typing.Any]
     :param accent: Accent Mode, Next typed character will strike through previous, for special character input
-    :type accent: bool
+    :type accent: typing.Union[bool, typing.Any]
     '''
 
     pass
@@ -330,93 +330,94 @@ def text_insert(override_context: typing.
 def text_paste(override_context: typing.
                Union[typing.Dict, 'bpy.types.Context'] = None,
                execution_context: typing.Union[str, int] = None,
-               undo: bool = None):
+               undo: typing.Optional[bool] = None):
     ''' Paste text from clipboard
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
 
 
-def text_paste_from_file(override_context: typing.
-                         Union[typing.Dict, 'bpy.types.Context'] = None,
-                         execution_context: typing.Union[str, int] = None,
-                         undo: bool = None,
-                         *,
-                         filepath: str = "",
-                         hide_props_region: bool = True,
-                         filter_blender: bool = False,
-                         filter_backup: bool = False,
-                         filter_image: bool = False,
-                         filter_movie: bool = False,
-                         filter_python: bool = False,
-                         filter_font: bool = False,
-                         filter_sound: bool = False,
-                         filter_text: bool = True,
-                         filter_archive: bool = False,
-                         filter_btx: bool = False,
-                         filter_collada: bool = False,
-                         filter_alembic: bool = False,
-                         filter_usd: bool = False,
-                         filter_obj: bool = False,
-                         filter_volume: bool = False,
-                         filter_folder: bool = True,
-                         filter_blenlib: bool = False,
-                         filemode: int = 9,
-                         display_type: typing.Union[str, int] = 'DEFAULT',
-                         sort_method: typing.Union[str, int] = ''):
+def text_paste_from_file(
+        override_context: typing.Union[typing.
+                                       Dict, 'bpy.types.Context'] = None,
+        execution_context: typing.Union[str, int] = None,
+        undo: typing.Optional[bool] = None,
+        *,
+        filepath: typing.Union[str, typing.Any] = "",
+        hide_props_region: typing.Union[bool, typing.Any] = True,
+        filter_blender: typing.Union[bool, typing.Any] = False,
+        filter_backup: typing.Union[bool, typing.Any] = False,
+        filter_image: typing.Union[bool, typing.Any] = False,
+        filter_movie: typing.Union[bool, typing.Any] = False,
+        filter_python: typing.Union[bool, typing.Any] = False,
+        filter_font: typing.Union[bool, typing.Any] = False,
+        filter_sound: typing.Union[bool, typing.Any] = False,
+        filter_text: typing.Union[bool, typing.Any] = True,
+        filter_archive: typing.Union[bool, typing.Any] = False,
+        filter_btx: typing.Union[bool, typing.Any] = False,
+        filter_collada: typing.Union[bool, typing.Any] = False,
+        filter_alembic: typing.Union[bool, typing.Any] = False,
+        filter_usd: typing.Union[bool, typing.Any] = False,
+        filter_obj: typing.Union[bool, typing.Any] = False,
+        filter_volume: typing.Union[bool, typing.Any] = False,
+        filter_folder: typing.Union[bool, typing.Any] = True,
+        filter_blenlib: typing.Union[bool, typing.Any] = False,
+        filemode: typing.Optional[typing.Any] = 9,
+        display_type: typing.Optional[typing.Any] = 'DEFAULT',
+        sort_method: typing.Union[str, int, typing.Any] = ''):
     ''' Paste contents from file
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param filepath: File Path, Path to file
-    :type filepath: str
+    :type filepath: typing.Union[str, typing.Any]
     :param hide_props_region: Hide Operator Properties, Collapse the region displaying the operator settings
-    :type hide_props_region: bool
+    :type hide_props_region: typing.Union[bool, typing.Any]
     :param filter_blender: Filter .blend files
-    :type filter_blender: bool
+    :type filter_blender: typing.Union[bool, typing.Any]
     :param filter_backup: Filter .blend files
-    :type filter_backup: bool
+    :type filter_backup: typing.Union[bool, typing.Any]
     :param filter_image: Filter image files
-    :type filter_image: bool
+    :type filter_image: typing.Union[bool, typing.Any]
     :param filter_movie: Filter movie files
-    :type filter_movie: bool
+    :type filter_movie: typing.Union[bool, typing.Any]
     :param filter_python: Filter python files
-    :type filter_python: bool
+    :type filter_python: typing.Union[bool, typing.Any]
     :param filter_font: Filter font files
-    :type filter_font: bool
+    :type filter_font: typing.Union[bool, typing.Any]
     :param filter_sound: Filter sound files
-    :type filter_sound: bool
+    :type filter_sound: typing.Union[bool, typing.Any]
     :param filter_text: Filter text files
-    :type filter_text: bool
+    :type filter_text: typing.Union[bool, typing.Any]
     :param filter_archive: Filter archive files
-    :type filter_archive: bool
+    :type filter_archive: typing.Union[bool, typing.Any]
     :param filter_btx: Filter btx files
-    :type filter_btx: bool
+    :type filter_btx: typing.Union[bool, typing.Any]
     :param filter_collada: Filter COLLADA files
-    :type filter_collada: bool
+    :type filter_collada: typing.Union[bool, typing.Any]
     :param filter_alembic: Filter Alembic files
-    :type filter_alembic: bool
+    :type filter_alembic: typing.Union[bool, typing.Any]
     :param filter_usd: Filter USD files
-    :type filter_usd: bool
+    :type filter_usd: typing.Union[bool, typing.Any]
     :param filter_obj: Filter OBJ files
-    :type filter_obj: bool
+    :type filter_obj: typing.Union[bool, typing.Any]
     :param filter_volume: Filter OpenVDB volume files
-    :type filter_volume: bool
+    :type filter_volume: typing.Union[bool, typing.Any]
     :param filter_folder: Filter folders
-    :type filter_folder: bool
+    :type filter_folder: typing.Union[bool, typing.Any]
     :param filter_blenlib: Filter Blender IDs
-    :type filter_blenlib: bool
+    :type filter_blenlib: typing.Union[bool, typing.Any]
     :param filemode: File Browser Mode, The setting for the file browser mode to load a .blend file, a library or a special file
-    :type filemode: int
-    :param display_type: Display Type * DEFAULT Default -- Automatically determine display type for files. * LIST_VERTICAL Short List -- Display files as short list. * LIST_HORIZONTAL Long List -- Display files as a detailed list. * THUMBNAIL Thumbnails -- Display files as thumbnails.
-    :type display_type: typing.Union[str, int]
+    :type filemode: typing.Optional[typing.Any]
+    :param display_type: Display Type * ``DEFAULT`` Default -- Automatically determine display type for files. * ``LIST_VERTICAL`` Short List -- Display files as short list. * ``LIST_HORIZONTAL`` Long List -- Display files as a detailed list. * ``THUMBNAIL`` Thumbnails -- Display files as thumbnails.
+    :type display_type: typing.Optional[typing.Any]
     :param sort_method: File sorting mode
-    :type sort_method: typing.Union[str, int]
+    :type sort_method: typing.Union[str, int, typing.Any]
     '''
 
     pass
@@ -425,12 +426,12 @@ def text_paste_from_file(override_context: typing.
 def textbox_add(override_context: typing.
                 Union[typing.Dict, 'bpy.types.Context'] = None,
                 execution_context: typing.Union[str, int] = None,
-                undo: bool = None):
+                undo: typing.Optional[bool] = None):
     ''' Add a new text box
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
@@ -439,16 +440,16 @@ def textbox_add(override_context: typing.
 def textbox_remove(override_context: typing.
                    Union[typing.Dict, 'bpy.types.Context'] = None,
                    execution_context: typing.Union[str, int] = None,
-                   undo: bool = None,
+                   undo: typing.Optional[bool] = None,
                    *,
-                   index: int = 0):
+                   index: typing.Optional[typing.Any] = 0):
     ''' Remove the text box
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param index: Index, The current text box
-    :type index: int
+    :type index: typing.Optional[typing.Any]
     '''
 
     pass
@@ -457,12 +458,12 @@ def textbox_remove(override_context: typing.
 def unlink(override_context: typing.Union[typing.
                                           Dict, 'bpy.types.Context'] = None,
            execution_context: typing.Union[str, int] = None,
-           undo: bool = None):
+           undo: typing.Optional[bool] = None):
     ''' Unlink active font data-block
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
