@@ -9,12 +9,12 @@ GenericType = typing.TypeVar("GenericType")
 def delete_metaelems(override_context: typing.
                      Union[typing.Dict, 'bpy.types.Context'] = None,
                      execution_context: typing.Union[str, int] = None,
-                     undo: bool = None):
+                     undo: typing.Optional[bool] = None):
     ''' Delete selected metaball element(s)
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
@@ -23,34 +23,35 @@ def delete_metaelems(override_context: typing.
 def duplicate_metaelems(override_context: typing.
                         Union[typing.Dict, 'bpy.types.Context'] = None,
                         execution_context: typing.Union[str, int] = None,
-                        undo: bool = None):
+                        undo: typing.Optional[bool] = None):
     ''' Duplicate selected metaball element(s)
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
 
 
-def duplicate_move(
-        override_context: typing.Union[typing.
-                                       Dict, 'bpy.types.Context'] = None,
-        execution_context: typing.Union[str, int] = None,
-        undo: bool = None,
-        *,
-        MBALL_OT_duplicate_metaelems: 'duplicate_metaelems' = None,
-        TRANSFORM_OT_translate: 'bpy.ops.transform.translate' = None):
+def duplicate_move(override_context: typing.
+                   Union[typing.Dict, 'bpy.types.Context'] = None,
+                   execution_context: typing.Union[str, int] = None,
+                   undo: typing.Optional[bool] = None,
+                   *,
+                   MBALL_OT_duplicate_metaelems: typing.
+                   Optional['duplicate_metaelems'] = None,
+                   TRANSFORM_OT_translate: typing.
+                   Optional['bpy.ops.transform.translate'] = None):
     ''' Make copies of the selected metaball elements and move them
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param MBALL_OT_duplicate_metaelems: Duplicate Metaball Elements, Duplicate selected metaball element(s)
-    :type MBALL_OT_duplicate_metaelems: 'duplicate_metaelems'
+    :type MBALL_OT_duplicate_metaelems: typing.Optional['duplicate_metaelems']
     :param TRANSFORM_OT_translate: Move, Move selected items
-    :type TRANSFORM_OT_translate: 'bpy.ops.transform.translate'
+    :type TRANSFORM_OT_translate: typing.Optional['bpy.ops.transform.translate']
     '''
 
     pass
@@ -59,16 +60,16 @@ def duplicate_move(
 def hide_metaelems(override_context: typing.
                    Union[typing.Dict, 'bpy.types.Context'] = None,
                    execution_context: typing.Union[str, int] = None,
-                   undo: bool = None,
+                   undo: typing.Optional[bool] = None,
                    *,
-                   unselected: bool = False):
+                   unselected: typing.Union[bool, typing.Any] = False):
     ''' Hide (un)selected metaball element(s)
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param unselected: Unselected, Hide unselected rather than selected
-    :type unselected: bool
+    :type unselected: typing.Union[bool, typing.Any]
     '''
 
     pass
@@ -77,16 +78,16 @@ def hide_metaelems(override_context: typing.
 def reveal_metaelems(override_context: typing.
                      Union[typing.Dict, 'bpy.types.Context'] = None,
                      execution_context: typing.Union[str, int] = None,
-                     undo: bool = None,
+                     undo: typing.Optional[bool] = None,
                      *,
-                     select: bool = True):
+                     select: typing.Union[bool, typing.Any] = True):
     ''' Reveal all hidden metaball elements
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param select: Select
-    :type select: bool
+    :type select: typing.Union[bool, typing.Any]
     '''
 
     pass
@@ -95,16 +96,16 @@ def reveal_metaelems(override_context: typing.
 def select_all(override_context: typing.
                Union[typing.Dict, 'bpy.types.Context'] = None,
                execution_context: typing.Union[str, int] = None,
-               undo: bool = None,
+               undo: typing.Optional[bool] = None,
                *,
-               action: typing.Union[str, int] = 'TOGGLE'):
+               action: typing.Optional[typing.Any] = 'TOGGLE'):
     ''' Change selection of all metaball elements
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
-    :param action: Action, Selection action to execute * TOGGLE Toggle -- Toggle selection for all elements. * SELECT Select -- Select all elements. * DESELECT Deselect -- Deselect all elements. * INVERT Invert -- Invert selection of all elements.
-    :type action: typing.Union[str, int]
+    :type undo: typing.Optional[bool]
+    :param action: Action, Selection action to execute * ``TOGGLE`` Toggle -- Toggle selection for all elements. * ``SELECT`` Select -- Select all elements. * ``DESELECT`` Deselect -- Deselect all elements. * ``INVERT`` Invert -- Invert selection of all elements.
+    :type action: typing.Optional[typing.Any]
     '''
 
     pass
@@ -113,22 +114,22 @@ def select_all(override_context: typing.
 def select_random_metaelems(override_context: typing.
                             Union[typing.Dict, 'bpy.types.Context'] = None,
                             execution_context: typing.Union[str, int] = None,
-                            undo: bool = None,
+                            undo: typing.Optional[bool] = None,
                             *,
-                            ratio: float = 0.5,
-                            seed: int = 0,
-                            action: typing.Union[str, int] = 'SELECT'):
+                            ratio: typing.Optional[typing.Any] = 0.5,
+                            seed: typing.Optional[typing.Any] = 0,
+                            action: typing.Optional[typing.Any] = 'SELECT'):
     ''' Randomly select metaball elements
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param ratio: Ratio, Portion of items to select randomly
-    :type ratio: float
+    :type ratio: typing.Optional[typing.Any]
     :param seed: Random Seed, Seed for the random number generator
-    :type seed: int
-    :param action: Action, Selection action to execute * SELECT Select -- Select all elements. * DESELECT Deselect -- Deselect all elements.
-    :type action: typing.Union[str, int]
+    :type seed: typing.Optional[typing.Any]
+    :param action: Action, Selection action to execute * ``SELECT`` Select -- Select all elements. * ``DESELECT`` Deselect -- Deselect all elements.
+    :type action: typing.Optional[typing.Any]
     '''
 
     pass
@@ -137,19 +138,19 @@ def select_random_metaelems(override_context: typing.
 def select_similar(override_context: typing.
                    Union[typing.Dict, 'bpy.types.Context'] = None,
                    execution_context: typing.Union[str, int] = None,
-                   undo: bool = None,
+                   undo: typing.Optional[bool] = None,
                    *,
-                   type: typing.Union[str, int] = 'TYPE',
-                   threshold: float = 0.1):
+                   type: typing.Optional[typing.Any] = 'TYPE',
+                   threshold: typing.Optional[typing.Any] = 0.1):
     ''' Select similar metaballs by property types
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param type: Type
-    :type type: typing.Union[str, int]
+    :type type: typing.Optional[typing.Any]
     :param threshold: Threshold
-    :type threshold: float
+    :type threshold: typing.Optional[typing.Any]
     '''
 
     pass
