@@ -4,10 +4,12 @@ import typing
 GenericType = typing.TypeVar("GenericType")
 
 
-def create_from_info(shader_info):
+def create_from_info(shader_info: typing.Any) -> typing.Any:
     ''' Create shader from a GPUShaderCreateInfo.
 
     :param shader_info: GPUShaderCreateInfo
+    :type shader_info: typing.Any
+    :rtype: typing.Any
     :return: Shader object corresponding to the given name.
     '''
 
