@@ -15,7 +15,7 @@ def blend_get():
 def blend_set(mode: str):
     ''' Defines the fixed pipeline blending equation.
 
-    :param mode: The type of blend mode. * NONE No blending. * ALPHA The original color channels are interpolated according to the alpha value. * ALPHA_PREMULT The original color channels are interpolated according to the alpha value with the new colors pre-multiplied by this value. * ADDITIVE The original color channels are added by the corresponding ones. * ADDITIVE_PREMULT The original color channels are added by the corresponding ones that are pre-multiplied by the alpha value. * MULTIPLY The original color channels are multiplied by the corresponding ones. * SUBTRACT The original color channels are subtracted by the corresponding ones. * INVERT The original color channels are replaced by its complementary color.
+    :param mode: The type of blend mode. * ``NONE`` No blending. * ``ALPHA`` The original color channels are interpolated according to the alpha value. * ``ALPHA_PREMULT`` The original color channels are interpolated according to the alpha value with the new colors pre-multiplied by this value. * ``ADDITIVE`` The original color channels are added by the corresponding ones. * ``ADDITIVE_PREMULT`` The original color channels are added by the corresponding ones that are pre-multiplied by the alpha value. * ``MULTIPLY`` The original color channels are multiplied by the corresponding ones. * ``SUBTRACT`` The original color channels are subtracted by the corresponding ones. * ``INVERT`` The original color channels are replaced by its complementary color.
     :type mode: str
     '''
 
@@ -23,7 +23,7 @@ def blend_set(mode: str):
 
 
 def clip_distances_set(distances_enabled: int):
-    ''' Sets the number of gl_ClipDistance planes used for clip geometry.
+    ''' Sets the number of `gl_ClipDistance` planes used for clip geometry.
 
     :param distances_enabled: Number of clip distances enabled.
     :type distances_enabled: int
@@ -56,11 +56,12 @@ def depth_mask_get():
     pass
 
 
-def depth_mask_set(value):
+def depth_mask_set(value: typing.Any):
     ''' Write to depth component.
 
     :type near: bool
     :param value:  True for writing to the depth component.
+    :type value: typing.Any
     '''
 
     pass
@@ -77,7 +78,7 @@ def depth_test_get():
 def depth_test_set(mode: str):
     ''' Defines the depth_test equation.
 
-    :param mode: The depth test equation name. Possible values are NONE , ALWAYS , LESS , LESS_EQUAL , EQUAL , GREATER and GREATER_EQUAL .
+    :param mode: The depth test equation name. Possible values are `NONE`, `ALWAYS`, `LESS`, `LESS_EQUAL`, `EQUAL`, `GREATER` and `GREATER_EQUAL`.
     :type mode: str
     '''
 
@@ -87,7 +88,7 @@ def depth_test_set(mode: str):
 def face_culling_set(culling):
     ''' Specify whether none, front-facing or back-facing facets can be culled.
 
-    :param mode: NONE , FRONT or BACK .
+    :param mode: `NONE`, `FRONT` or `BACK`.
     :type mode: str
     '''
 
@@ -102,11 +103,12 @@ def framebuffer_active_get(enable):
     pass
 
 
-def front_facing_set(invert):
+def front_facing_set(invert: typing.Any):
     ''' Specifies the orientation of front-facing polygons.
 
     :type mode: bool
     :param invert:  True for clockwise polygons as front-facing.
+    :type invert: typing.Any
     '''
 
     pass
@@ -125,16 +127,18 @@ def line_width_set(width):
 
     :type mode: float
     :param size:  New width.
+    :type size: typing.Any
     '''
 
     pass
 
 
-def point_size_set(size):
+def point_size_set(size: typing.Any):
     ''' Specify the diameter of rasterized points.
 
     :type mode: float
     :param size:  New diameter.
+    :type size: typing.Any
     '''
 
     pass
@@ -168,7 +172,9 @@ def viewport_set(x: int, y: int, xsize: int, ysize: int):
     :type xsize: int
     :type ysize: int
     :param width:  width and height of the viewport_set.
+    :type width: typing.Any
     :param height:  width and height of the viewport_set.
+    :type height: typing.Any
     '''
 
     pass
