@@ -2,6 +2,8 @@ import sys
 import typing
 import nodeitems_utils
 
+GenericType = typing.TypeVar("GenericType")
+
 
 class SortedNodeCategory(nodeitems_utils.NodeCategory):
     def poll(self, _context):
@@ -99,14 +101,6 @@ def geometry_node_items(context):
     pass
 
 
-def geometry_nodes_legacy_poll(context):
-    ''' 
-
-    '''
-
-    pass
-
-
 def group_input_output_item_poll(context):
     ''' 
 
